import React, { ComponentType, FC, MouseEventHandler } from 'react';
import { Button, ButtonProps, Spinner, SpinnerProps } from 'react-bootstrap';
// import '../../node_modules/bootstrap/dist/css/bootstrap.min.css';

export type ReactBootstrapButtonProps = {
	bsButtonProps?: Omit<ButtonProps, 'children'>;
	isLoading?: boolean;
	disabled?: boolean;
	loaderPosition?: 'left' | 'right';
	loaderProps?: SpinnerProps;
	loadingMessage?: string;
	icon?: ComponentType<object>;
	onClick?: MouseEventHandler<HTMLButtonElement>;
};

const ReactBootstrapButton: FC<ReactBootstrapButtonProps> = ({
	bsButtonProps,
	isLoading,
	disabled,
	loaderPosition,
	loaderProps,
	loadingMessage,
	icon,
	children,
	onClick,
	...rest
}) => {
	return (
		<Button
			className="px-3"
			{...bsButtonProps}
			{...rest}
			disabled={isLoading || disabled}
			onClick={onClick}
		>
			<div className="d-flex justify-content-between align-items-center mx-2">
				{isLoading && loaderPosition === 'left' && (
					<Spinner animation="border" size="sm" {...loaderProps} />
				)}
				{!isLoading && icon}
				<div className="mx-2">
					{isLoading && loadingMessage ? loadingMessage : children || 'Button'}
				</div>
				{isLoading && loaderPosition === 'right' && (
					<Spinner animation="border" size="sm" />
				)}
			</div>
		</Button>
	);
};

export default ReactBootstrapButton;
ReactBootstrapButton.defaultProps = {
	loaderPosition: 'left',
};
